<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../cmd.cpp" line="79"/>
        <source>Administrator Access Required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../cmd.cpp" line="80"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Detectado sistema externo en execución. Seleccionar a partición do sistema a modificar (son exhibidas só particións Linux)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Usar estrutura de menú simplificada, sen submenús</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Usar menús simples (sen submenús)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Arranque para</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Establecer 0 para cargar de inmediato a escolla predeterminada sen exhibir o menú de opcións de arranque, ou -1 para manter o menú en espera</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Tempo de espera</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Parámetros do núcleo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Con está opción activada, a escolla de opción de arranque que for feita no GRUB será gardada como a nova predeterminada para os arranques futuros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Gardar a última escolla de arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Xestionar opcións de arranque UEFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Imaxe de fondo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Imaxe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Activar tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Máscara</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Mensaxes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Presentación completa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Presentación normal (predeterminada)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Presentación limitada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Amosar o rexistro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Amosar axuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Sobre esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Saír do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>Still running</source>
        <translation>Aínda executándose</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Set timeout</source>
        <translation>Establecer tempo de espera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Timeout in seconds:</source>
        <translation>Tempo de espera en segundos:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <location filename="../mainwindow.cpp" line="631"/>
        <location filename="../mainwindow.cpp" line="1448"/>
        <source>Timeout: %1 seconds</source>
        <translation>Tempo de espera: %1 segundos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <location filename="../mainwindow.cpp" line="633"/>
        <location filename="../mainwindow.cpp" line="1447"/>
        <location filename="../mainwindow.cpp" line="1455"/>
        <source>Boot Next: %1</source>
        <translation>Arranque seguinte: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Removal confirmation</source>
        <translation>Confirmación de eliminación</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation>Estás seguro de que queres eliminar esta entrada de arranque?
%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Select EFI file</source>
        <translation>Seleccionar ficheiro EFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation>Ficheiros EFI (*.efi *.EFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="431"/>
        <location filename="../mainwindow.cpp" line="446"/>
        <location filename="../mainwindow.cpp" line="532"/>
        <location filename="../mainwindow.cpp" line="540"/>
        <location filename="../mainwindow.cpp" line="574"/>
        <location filename="../mainwindow.cpp" line="616"/>
        <location filename="../mainwindow.cpp" line="716"/>
        <location filename="../mainwindow.cpp" line="805"/>
        <location filename="../mainwindow.cpp" line="1648"/>
        <location filename="../mainwindow.cpp" line="1661"/>
        <location filename="../mainwindow.cpp" line="1667"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation>Non se puido atopar o punto de montaxe da fonte para %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Set name</source>
        <translation>Establecer nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation>Introduza o nome para o item do menu UEFI:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>Something went wrong, could not add entry.</source>
        <translation>Algo saiu mal, non se puido engadir a entrada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Instalando máscara, agarde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Updating sources</source>
        <translation>Actualizando as orixes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>Could not install the bootsplash.</source>
        <translation>A máscara non foi instalada.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="616"/>
        <source>Failed to get UEFI boot entries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="635"/>
        <source>Boot Current: %1</source>
        <translation>Arranque actual: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="716"/>
        <source>Could not create a temporary folder</source>
        <translation>Non foi posíbel crear un cartafol temporal </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="725"/>
        <location filename="../mainwindow.cpp" line="745"/>
        <source>Cannot continue</source>
        <translation>Imposible continuar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="725"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="746"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Non é posible crear un ambiente chroot. Non é posible cambiar as opcións de arranque. Saíndo...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="805"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation>Algo saiu mal, non se puido gardar a orde de arranque.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1090"/>
        <location filename="../mainwindow.cpp" line="1568"/>
        <source>Updating configuration, please wait</source>
        <translation>Actualizando a configuración, agarda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1161"/>
        <source>Updating initramfs...</source>
        <translation>Actualizando o initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <location filename="../mainwindow.cpp" line="1583"/>
        <source>Updating grub...</source>
        <translation>Actualizando o GRUB...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1200"/>
        <source>About %1</source>
        <translation>Sobre %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1201"/>
        <source>Version: </source>
        <translation>Versión: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1203"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programa para seleccionar opcións de iniciación comúns</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1205"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1206"/>
        <source>%1 License</source>
        <translation>Licenza de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1227"/>
        <source>%1 Help</source>
        <translation>Axuda para %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1237"/>
        <location filename="../mainwindow.cpp" line="1545"/>
        <source>Running in a Virtual Machine</source>
        <translation>Executándose nunha máquina virtual</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1238"/>
        <location filename="../mainwindow.cpp" line="1546"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>O sistema está a ser executado nunha máquina virtual.
A máscara do arranque Plymouth será executada con limitacións. Tamén non será posible previsualizar o tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1245"/>
        <source>Plymouth packages not installed</source>
        <translation>Paquetes do Plymouth non instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1246"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Os paquetes do Plymouth non están instalados.
Continuar e instalar estes paquetes?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1272"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Imaxes (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1414"/>
        <source>Log not found</source>
        <translation>Rexistro non atopado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1414"/>
        <source>Could not find log at </source>
        <translation>Non foi atopado rexistro en</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1421"/>
        <source>Edit UEFI Boot Entries</source>
        <translation>Editar entradas de arranque UEFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1424"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation>Pode usar os botóns Arriba/Abaixo ou arrastrar e soltar elementos para cambiar a orde de arranque.
- Os elementos están listados na orde de arranque.
- As liñas grisadas están inactivas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1435"/>
        <location filename="../mainwindow.cpp" line="1483"/>
        <source>Set ac&amp;tive</source>
        <translation>Configurar como ac&amp;tivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1436"/>
        <source>&amp;Add entry</source>
        <translation>Eng&amp;adir entrada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1437"/>
        <source>Boot &amp;next</source>
        <translation>Arra&amp;nque seguinte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1648"/>
        <source>Could not retrieve UUID for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1656"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1661"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1667"/>
        <source>Could not open %1 LUKS container</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1403"/>
        <location filename="../mainwindow.cpp" line="1438"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>O proceso segue en execución. Estás seguro de que queres saír?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <source>Live System Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Live System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="172"/>
        <source>Installed System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Failed to update package sources.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Installing packages:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="546"/>
        <source>Success</source>
        <translation>Con éxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="546"/>
        <source>Bootsplash installed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>Failed to create temporary file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1183"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1185"/>
        <source>Your changes have been successfully applied.</source>
        <translation>Cambios aplicados con éxito.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1186"/>
        <source>Operation Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1271"/>
        <source>Select image to display in bootloader</source>
        <translation>Seleccionar a imaxe de fondo do cargador do arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1395"/>
        <source>Boot Log</source>
        <translation>Rexistro de arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1439"/>
        <source>Move &amp;down</source>
        <translation>Mover abaixo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1440"/>
        <source>&amp;Remove entry</source>
        <translation>Elimina&amp;r entrada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1441"/>
        <source>Re&amp;set next</source>
        <translation>Repor &amp;seguinte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1442"/>
        <source>Change &amp;timeout</source>
        <translation>Cambiar &amp;tempo de espera</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1443"/>
        <source>Move &amp;up</source>
        <translation>Mover arriba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1447"/>
        <location filename="../mainwindow.cpp" line="1455"/>
        <source>not set, will boot using list order</source>
        <translation>non configurado, arrincará usando a orde da lista</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1480"/>
        <source>Set &amp;inactive</source>
        <translation>Configurar como &amp;inactivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1534"/>
        <source>Needs reboot</source>
        <translation>É necesario reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1535"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth acabou de ser instalado. Pode ser necesario reiniciar para exhibir as previsualizacións</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1604"/>
        <source>Click to select theme</source>
        <translation>Premer para seleccionar o tema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1615"/>
        <source>Select GRUB theme</source>
        <translation>Seleccionar o tema do GRUB</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Programa para seleccionar opcións de iniciación comúns</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="55"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="56"/>
        <location filename="../about.cpp" line="65"/>
        <source>Changelog</source>
        <translation>Rexistro dos cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="57"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <location filename="../main.cpp" line="90"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>O usuario parece ser root; para usar este programa, pechar a sesión e iniciar sesión como usuario normal.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>You must run this program with admin access.</source>
        <translation>Debes executar este programa con acceso de administrador.</translation>
    </message>
</context>
</TS>
